
# -*- coding: utf-8 -*-
import re
import sys

from pypeit.scripts.show_2dspec import Show2DSpec

if __name__ == '__main__':
    sys.argv[0] = re.sub(r'(-script\.pyw?|\.exe)?$', '', sys.argv[0])
    sys.exit(Show2DSpec.entry_point())
